      subroutine compute_hsriremis( 
     & cyear,           ! in
     & cmonth,          ! in
     & lat_site,        ! in
     & lon_site,        ! in
     & first,           ! in
     & instr_switch,    ! in
     & debug,           ! in
     & hsriremis,       ! out
     % nchs,            ! in
     & instr_wn,        ! in, optional
     & instr_emis)      ! out, optional

c --------------------------------------------------------------------
    ! Description:
    !software to create library to compute high spectral resolution emissivity spectra 
    ! from the MEASURES CAMEL (Combined ASTER MODIS Emissivity over Land)
    !
    ! History:
    ! Version   Date     Comment
    ! -------   ----     -------
    !  0.6     05/11/2016  Original code E Borbas UW-Madison/CIMSS
    !  1.0     01/10/2017  Adjusted to the MEASUREs CAMEL products Version V001 (v01r02)
    !  2.0     10/09/2018  Adjusted to the MEASUREs CAMEL products Version V002 (v02r01)
    !
    ! Code Description:
    !   Language:           Fortran 90.
    !   Software Standards: "European Standards for Writing and
    !   Documenting Exchangeable Fortran 90 Code".
    !
    !
    ! Input parameters:
    !
    !       cyear:  year
    !       cmonth: month
    !       lat_site: latitude of the pixel
    !       lon_site: longitude of teh pixel
    !       first: logical parameter if it is a first call or not
    !       instr_switch: logical parameter if the hsr shoudl be calucalted for a certain instruments
    !       debug: logical parameter for debuging
    !       instr_wn: optional intut: central wave number of the instrument bands
    !
    ! Output parameters: 
    !       hsriremis:  hsr IR emissivity
    !       instr_emis: Emissivity calucalted for the isntrument bands
    !
    ! Calls
    !      init_hsriremis
    !      read_CAMEL_coef  
    !      recon_hsriremis            
    !      select_wavenum
    ! 
!-------------------------------------------------------------

      Implicit None
      
      include 'hsriremis_EDR.inc'

       Integer, Parameter :: nmonth=12
       Integer year, month
       integer nchs
 
       Character (len=4) :: cyear
       Character (len=2) :: cmonth
       !Character (len=6) :: prd_ver

       INTEGER :: err, errorstatus_fatal,errorstatus_success
       INTEGER :: i, j,ios
       INTEGER:: gridy, gridx
       
       REAL :: lat_site, lon_site
       INTEGER :: ilat, ilon
 
        REAL  :: hsriremis(numwave)
        
	Real,    Intent(in), Optional :: instr_wn(nchs)
	Real,    Intent(out), Optional :: instr_emis(nchs)
        
       LOGICAL :: file_exists
       LOGICAL :: instr_switch
       LOGICAL :: first
       LOGICAL :: debug

!---------------------------------------
! check arguments

        if(debug) write(*,*) 'inputs=  ',cyear,cmonth,lat_site,lon_site,instr_switch
 
!----------------------------
! checking if the CAMEL coef data file exists
     
        fn_coef=TRIM(path_camel)//'CAMEL_coef_'//cyear//cmonth//'_'//LP_DAAC_version//'.nc'

	Inquire(FILE=fn_coef, EXIST=file_exists)
        If (.not. file_exists) Then
           err = errorstatus_fatal
           write(*,*)  'CAMEL coef file not found : ',Trim(fn_coef)
           return
        End If
    
!----------------------------
! get the grid coordinates 
 
      ilat = NInt(lat_site*1000.)
      ilon = NInt(lon_site*1000.)

      gridy = NInt(Abs(ygrid1-ilat)*1./gridres)+1
      gridx = NInt(Abs(xgrid1-ilon)*1./gridres)+1
 	
!----------------------------
! init isntr_emis
!	 do i=1,nchs
!	 instr_emis(i)=hkod
!         enddo
!----------------------------
! read PCS of laboratory data - init

        if(first) then

!        call init_hsriremis(fn_coef)
        call init_hsriremis

       write(*,*) 'Reading CAMEL coef data: ',Trim(fn_coef)
        Call read_CAMEL_coef(fn_coef, camel_qflag)
    
       endif
	  
!----------------------------
! read CAMEL coef data

!moved to init       write(*,*) 'Reading CAMEL coef data: ',Trim(fn_coef)
!       Call read_CAMEL_coef(fn_coef)
           
        instr_emis_flag = camel_qflag(gridx,gridy)
        labvs=pc_labvs(coef_lut(gridx,gridy))
        npcs=pc_npcs(coef_lut(gridx,gridy))
        snow_frac=real(snowf(coef_lut(gridx,gridy)))*snow_scale_factor

             
      if(debug)write(*,*) 'lat_site= ', lat_site
      if(debug)write(*,*) 'lon_site= ', lon_site
      if(debug)write(*,*) 'gridx=    ', gridx
      if(debug)write(*,*) 'gridy=    ', gridy
      if(debug)write(*,*) 'snow_frac= ',snow_frac
      if(debug)write(*,*) 'labvs=     ',labvs
      if(debug)write(*,*) 'numberpcs= ',npcs
      if(debug)write(*,*) 'instr_emis_flag= ',instr_emis_flag
                 
    !------------------------------
    ! check if it is a land pixel

      coeff = 0. 
            
      If ( instr_emis_flag > 0 ) Then
      
        If (coef_lut(gridx,gridy) > 0) Then

               coeff(:) = pcacoefs(1:npcs,coef_lut(gridx,gridy))*pca_sfac + pca_offs
        Else
          Return
        End If
	
	if(debug)write(*,*)  'coeff= ',coeff
	
    !----------------------------
    ! calcualte hsr emis
	
            call recon_hsriremis( npcs,labvs,coeff,hsriremis)   
	    if(debug)write(*,*) 'hsriremis = ',hsriremis 
        
    !----------------------------
    ! calcualte instr emis of isntr_switch is TRUE

            If (instr_switch) Then  
	  	       
                 call select_wavenum( hsriremis,nchs,instr_wn,instr_emis)   
	
            End If   ! Instr_switch
      
!       Else
       
!            hsriremis = hkod
!	    return

       
       Else
       
             Write(*,*) 'Location is not over Land!!!'
	     return
       
       End If  ! land pixel
	
       	
	 
      End Subroutine compute_hsriremis
 
